@@ -81,7 +81,7 @@ display.parameters_model <- function(object,
                                      footer = NULL,
                                      align = NULL,
                                      digits = 2,
-                                     ci_digits = 2,
+                                     ci_digits = digits,
                                      p_digits = 3,
                                      footer_digits = 3,
                                      ci_brackets = c("(", ")"),
@@ -91,6 +91,7 @@ display.parameters_model <- function(object,
                                      font_size = "100%",
                                      line_padding = 4,
                                      column_labels = NULL,
+                                     include_reference = FALSE,
                                      verbose = TRUE,
                                      ...) {
   if (identical(format, "html")) {
@@ -132,7 +133,7 @@ display.parameters_brms_meta <- display.parameters_model
 display.compare_parameters <- function(object,
                                        format = "markdown",
                                        digits = 2,
-                                       ci_digits = 2,
+                                       ci_digits = digits,
                                        p_digits = 3,
                                        select = NULL,
                                        column_labels = NULL,
@@ -165,7 +166,7 @@ display.compare_parameters <- function(object,
 display.parameters_sem <- function(object,
                                    format = "markdown",
                                    digits = 2,
-                                   ci_digits = 2,
+                                   ci_digits = digits,
                                    p_digits = 3,
                                    ci_brackets = c("(", ")"),
                                    ...) {
