@@ -306,7 +306,7 @@ equivalence_test.ggeffects <- function(x,
                                        test = "pairwise",
                                        verbose = TRUE,
                                        ...) {
-  insight::check_if_installed("ggeffects", minimum_version = "1.2.0")
+  insight::check_if_installed("ggeffects")
 
   # get attributes from ggeffects objects, so we have the original model and terms
   focal <- attributes(x)$original.terms
@@ -693,7 +693,7 @@ equivalence_test.ggeffects <- function(x,
 #' @export
 format.equivalence_test_lm <- function(x,
                                        digits = 2,
-                                       ci_digits = 2,
+                                       ci_digits = digits,
                                        p_digits = 3,
                                        ci_width = NULL,
                                        ci_brackets = NULL,
@@ -736,7 +736,7 @@ format.equivalence_test_lm <- function(x,
 #' @export
 print.equivalence_test_lm <- function(x,
                                       digits = 2,
-                                      ci_digits = 2,
+                                      ci_digits = digits,
                                       p_digits = 3,
                                       ci_brackets = NULL,
                                       zap_small = FALSE,
@@ -794,7 +794,7 @@ plot.equivalence_test_lm <- function(x, ...) {
 #' #' @export
 #' print_md.equivalence_test_lm <- function(x,
 #'                                          digits = 2,
-#'                                          ci_digits = 2,
+#'                                          ci_digits = digits,
 #'                                          p_digits = 3,
 #'                                          ci_brackets = NULL,
 #'                                          zap_small = FALSE,
