@@ -8,13 +8,14 @@ format.parameters_model <- function(x,
                                     split_components = TRUE,
                                     select = NULL,
                                     digits = 2,
-                                    ci_digits = 2,
+                                    ci_digits = digits,
                                     p_digits = 3,
                                     ci_width = NULL,
                                     ci_brackets = NULL,
                                     zap_small = FALSE,
                                     format = NULL,
                                     groups = NULL,
+                                    include_reference = FALSE,
                                     ...) {
   # save attributes
   coef_name <- attributes(x)$coefficient_name
@@ -167,6 +168,7 @@ format.parameters_model <- function(x,
       ci_width = ci_width,
       ci_brackets = ci_brackets,
       zap_small = zap_small,
+      include_reference = include_reference,
       ...
     )
   } else {
@@ -183,6 +185,7 @@ format.parameters_model <- function(x,
       format = format,
       coef_name = coef_name,
       zap_small = zap_small,
+      include_reference = include_reference,
       ...
     )
   }
@@ -202,16 +205,16 @@ format.parameters_model <- function(x,
   # to "split" the formatted table, because the glue-function needs the columns
   # without the parameters-column.
   if (!is.null(style)) {
-    if (!is.data.frame(formatted_table)) {
-      formatted_table[] <- lapply(
+    if (is.data.frame(formatted_table)) {
+      formatted_table <- .style_formatted_table(
         formatted_table,
-        .style_formatted_table,
         style = style,
         format = format
       )
     } else {
-      formatted_table <- .style_formatted_table(
+      formatted_table[] <- lapply(
         formatted_table,
+        .style_formatted_table,
         style = style,
         format = format
       )
@@ -259,7 +262,7 @@ format.compare_parameters <- function(x,
                                       split_components = TRUE,
                                       select = NULL,
                                       digits = 2,
-                                      ci_digits = 2,
+                                      ci_digits = digits,
                                       p_digits = 3,
                                       ci_width = NULL,
                                       ci_brackets = NULL,
@@ -468,16 +471,23 @@ format.compare_parameters <- function(x,
 #' @export
 format.parameters_sem <- function(x,
                                   digits = 2,
-                                  ci_digits = 2,
+                                  ci_digits = digits,
                                   p_digits = 3,
                                   format = NULL,
                                   ci_width = NULL,
                                   ci_brackets = TRUE,
                                   pretty_names = TRUE,
                                   ...) {
-  if (missing(digits)) digits <- .additional_arguments(x, "digits", 2)
-  if (missing(ci_digits)) ci_digits <- .additional_arguments(x, "ci_digits", 2)
-  if (missing(p_digits)) p_digits <- .additional_arguments(x, "p_digits", 3)
+  if (missing(digits)) {
+    digits <- .additional_arguments(x, "digits", 2)
+  }
+  if (missing(ci_digits)) {
+    ci_digits <- .additional_arguments(x, "ci_digits", digits)
+  }
+  if (missing(p_digits)) {
+    p_digits <- .additional_arguments(x, "p_digits", 3)
+  }
+
   .format_columns_multiple_components(
     x,
     pretty_names = TRUE,
@@ -824,9 +834,9 @@ format.parameters_sem <- function(x,
         }
 
         string_tailed <- switch(ci_method,
-          "hdi" = "highest-density",
-          "uniroot" = ,
-          "profile" = "profile-likelihood",
+          hdi = "highest-density",
+          uniroot = ,
+          profile = "profile-likelihood",
           "equal-tailed"
         )
 
@@ -840,15 +850,15 @@ format.parameters_sem <- function(x,
         }
 
         string_method <- switch(ci_method,
-          "bci" = ,
-          "bcai" = "bias-corrected accelerated bootstrap",
-          "si" = ,
-          "ci" = ,
-          "quantile" = ,
-          "eti" = ,
-          "hdi" = sampling_method,
-          "normal" = "Wald normal",
-          "boot" = "parametric bootstrap",
+          bci = ,
+          bcai = "bias-corrected accelerated bootstrap",
+          si = ,
+          ci = ,
+          quantile = ,
+          eti = ,
+          hdi = sampling_method,
+          normal = "Wald normal",
+          boot = "parametric bootstrap",
           "Wald"
         )
 
@@ -860,9 +870,9 @@ format.parameters_sem <- function(x,
 
         if (!is.null(test_statistic) && !ci_method == "normal" && !isTRUE(bootstrap)) {
           string_statistic <- switch(tolower(test_statistic),
-            "t-statistic" = "t",
-            "chi-squared statistic" = ,
-            "z-statistic" = "z",
+            `t-statistic` = "t",
+            `chi-squared statistic` = ,
+            `z-statistic` = "z",
             ""
           )
           string_method <- paste0(string_method, " ", string_statistic, "-")
@@ -918,7 +928,7 @@ format.parameters_sem <- function(x,
     if (!is.null(msg) && isTRUE(getOption("parameters_warning_exponentiate", TRUE))) {
       insight::format_alert(paste0("\n", msg))
       # set flag, so message only displayed once per session
-      options("parameters_warning_exponentiate" = FALSE)
+      options(parameters_warning_exponentiate = FALSE)
     }
   }
 }
