@@ -4,6 +4,8 @@ model_parameters.merModList <- function(model,
                                         ci = 0.95,
                                         exponentiate = FALSE,
                                         p_adjust = NULL,
+                                        keep = NULL,
+                                        drop = NULL,
                                         verbose = TRUE,
                                         ...) {
   out <- .model_parameters_generic(
@@ -14,11 +16,13 @@ model_parameters.merModList <- function(model,
     merge_by = "Parameter",
     standardize = NULL,
     exponentiate = exponentiate,
+    keep_parameters = keep,
+    drop_parameters = drop,
     p_adjust = p_adjust,
     ...
   )
 
-  attr(out, "object_name") <- deparse(substitute(model), width.cutoff = 500)
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(model))
   out
 }
 
