@@ -87,6 +87,11 @@
 #'   labels will be used as parameters names. The latter only works for "labelled"
 #'   data, i.e. if the data used to fit the model had `"label"` and `"labels"`
 #'   attributes. See also section _Global Options to Customize Messages when Printing_.
+#' @param include_reference Logical, if `TRUE`, the reference level of factors will
+#'   be added to the parameters table. This is only relevant for models with
+#'   categorical predictors. The coefficient for the reference level is always
+#'   `0` (except when `exponentiate = TRUE`, then the coefficient will be `1`),
+#'   so this is just for completeness.
 #' @inheritParams insight::format_table
 #' @inheritParams compare_parameters
 #'
@@ -224,7 +229,7 @@ print.parameters_model <- function(x,
                                    caption = NULL,
                                    footer = NULL,
                                    digits = 2,
-                                   ci_digits = 2,
+                                   ci_digits = digits,
                                    p_digits = 3,
                                    footer_digits = 3,
                                    show_sigma = FALSE,
@@ -233,6 +238,7 @@ print.parameters_model <- function(x,
                                    groups = NULL,
                                    column_width = NULL,
                                    ci_brackets = c("[", "]"),
+                                   include_reference = FALSE,
                                    ...) {
   # save original input
   orig_x <- x
@@ -256,7 +262,7 @@ print.parameters_model <- function(x,
     digits <- .additional_arguments(x, "digits", digits)
   }
   if (missing(ci_digits)) {
-    ci_digits <- .additional_arguments(x, "ci_digits", ci_digits)
+    ci_digits <- .additional_arguments(x, "ci_digits", digits)
   }
   if (missing(p_digits)) {
     p_digits <- .additional_arguments(x, "p_digits", p_digits)
@@ -282,6 +288,7 @@ print.parameters_model <- function(x,
     ci_brackets = ci_brackets,
     format = "text",
     groups = groups,
+    include_reference = include_reference,
     ...
   )
 
@@ -364,20 +371,6 @@ print.parameters_random <- function(x, digits = 2, ...) {
 
 
 
-# Stan models ------------------
-
-#' @export
-print.parameters_stan <- print.parameters_model
-
-#' @export
-summary.parameters_stan <- function(object, ...) {
-  print(x = object, select = "minimal", show_formula = TRUE, ...)
-}
-
-
-
-
-
 # helper --------------------
 
 .print_core <- function(x,
@@ -385,13 +378,14 @@ summary.parameters_stan <- function(object, ...) {
                         split_components = TRUE,
                         select = NULL,
                         digits = 2,
-                        ci_digits = 2,
+                        ci_digits = digits,
                         p_digits = 3,
                         zap_small = FALSE,
                         ci_width = "auto",
                         ci_brackets = TRUE,
                         format = "text",
                         group = NULL,
+                        include_reference = FALSE,
                         ...) {
   format(
     x,
@@ -406,6 +400,7 @@ summary.parameters_stan <- function(object, ...) {
     zap_small = zap_small,
     format = format,
     group = group,
+    include_reference = include_reference,
     ...
   )
 }
