@@ -11,7 +11,7 @@ print_html.parameters_model <- function(x,
                                         footer = NULL,
                                         align = NULL,
                                         digits = 2,
-                                        ci_digits = 2,
+                                        ci_digits = digits,
                                         p_digits = 3,
                                         footer_digits = 3,
                                         ci_brackets = c("(", ")"),
@@ -22,6 +22,7 @@ print_html.parameters_model <- function(x,
                                         font_size = "100%",
                                         line_padding = 4,
                                         column_labels = NULL,
+                                        include_reference = FALSE,
                                         verbose = TRUE,
                                         ...) {
   # check if user supplied digits attributes
@@ -30,7 +31,7 @@ print_html.parameters_model <- function(x,
   }
 
   if (missing(ci_digits)) {
-    ci_digits <- .additional_arguments(x, "ci_digits", ci_digits)
+    ci_digits <- .additional_arguments(x, "ci_digits", digits)
   }
 
   if (missing(p_digits)) {
@@ -82,6 +83,7 @@ print_html.parameters_model <- function(x,
     ci_brackets = ci_brackets,
     format = "html",
     groups = groups,
+    include_reference = include_reference,
     ...
   )
 
@@ -100,9 +102,9 @@ print_html.parameters_model <- function(x,
     format = "html"
   )
   if (!is.null(footer)) {
-    footer <- paste0(footer, "<br/>", paste(footer_stats, collapse = "<br/>"))
-  } else {
-    footer <- paste(footer_stats, collapse = "<br/>")
+    footer <- paste0(footer, "<br>", paste(footer_stats, collapse = "<br>"))
+  } else if (!is.null(footer_stats)) {
+    footer <- paste(footer_stats, collapse = "<br>")
   }
 
   out <- insight::export_table(
@@ -139,7 +141,7 @@ print_html.compare_parameters <- function(x,
                                           subtitle = NULL,
                                           footer = NULL,
                                           digits = 2,
-                                          ci_digits = 2,
+                                          ci_digits = digits,
                                           p_digits = 3,
                                           zap_small = FALSE,
                                           groups = NULL,
@@ -155,7 +157,7 @@ print_html.compare_parameters <- function(x,
   }
 
   if (missing(ci_digits)) {
-    ci_digits <- .additional_arguments(x, "ci_digits", ci_digits)
+    ci_digits <- .additional_arguments(x, "ci_digits", digits)
   }
 
   if (missing(p_digits)) {
@@ -235,8 +237,10 @@ print_html.compare_parameters <- function(x,
     )
     new_labels <- as.list(new_labels)
   }
-  # add a column span?
-  if (!is.null(original_colnames) && any(duplicated(original_colnames))) {
+  # add a column span? here we have multiple columns (like estimate, CI, p, ...)
+  # for each model. In this case, we want to add a column spanner, i.e. a
+  # separate heading for all columns of each model.
+  if (!is.null(original_colnames) && anyDuplicated(original_colnames) > 0) {
     duplicates <- original_colnames[duplicated(original_colnames)]
     for (d in duplicates) {
       # we need +1 here, because first column is parameter column
@@ -244,7 +248,11 @@ print_html.compare_parameters <- function(x,
       # add column spanner
       out <- gt::tab_spanner(out, label = d, columns = span)
     }
-    # relabel columns
+    # relabel columns. The single columns still have their old labels
+    # (like "Estimate (model1)", "p (model1)"), and we extracted the "model names"
+    # and used them for the column spanner. Now we no longer need this suffix,
+    # and remove it. In case user-defined column labels are provided, "new_labels"
+    # is not NULL, so we use user labels, else we extract labels from columns.
     if (!is.null(column_names)) {
       if (is.null(new_labels)) {
         new_labels <- as.list(gsub("(.*) \\((.*)\\)$", "\\1", column_names))
@@ -252,7 +260,7 @@ print_html.compare_parameters <- function(x,
       names(new_labels) <- column_names
       out <- gt::cols_label(out, .list = new_labels)
     }
-    # default column label
+    # default column label, if we have user labels
   } else if (!is.null(new_labels)) {
     names(new_labels) <- colnames(out[["_data"]])
     out <- gt::cols_label(out, .list = new_labels)
