@@ -77,7 +77,7 @@ reduce_parameters <- function(x, method = "PCA", n = "max", distance = "euclidea
 #' @export
 reduce_data <- function(x, method = "PCA", n = "max", distance = "euclidean", ...) {
   if (!is.data.frame(x)) {
-    stop("Only works on data frames.", call. = FALSE)
+    insight::format_error("Only works on data frames.")
   }
   reduce_parameters(x, method = method, n = n, distance = distance, ...)
 }
@@ -204,7 +204,9 @@ principal_components.merMod <- principal_components.lm
 
   insight::check_if_installed("DRR")
 
-  junk <- utils::capture.output(suppressMessages(rez <- DRR::drr(x, n)))
+  junk <- utils::capture.output(suppressMessages({
+    rez <- DRR::drr(x, n)
+  }))
 
   features <- as.data.frame(rez$fitted.data)
   names(features) <- paste0("DRR", seq_len(ncol(features)))
