@@ -24,18 +24,20 @@
 #' standardize_info(model, two_sd = TRUE)
 #' @aliases standardise_info
 #' @export
-standardize_info <- function(model, robust = FALSE, two_sd = FALSE, include_pseudo = FALSE, ...) {
+standardize_info <- function(model, ...) {
   UseMethod("standardize_info")
 }
 
 #' @export
 standardise_info <- standardize_info
 
+#' @rdname standardize_info
 #' @export
 standardize_info.default <- function(model,
                                      robust = FALSE,
                                      two_sd = FALSE,
                                      include_pseudo = FALSE,
+                                     verbose = TRUE,
                                      ...) {
   # check for valid input
   .is_model_valid(model)
@@ -50,12 +52,12 @@ standardize_info.default <- function(model,
   types <- parameters_type(model)
   # model_matrix <- as.data.frame(stats::model.matrix(model))
   model_matrix <- as.data.frame(insight::get_modelmatrix(model))
-  data <- insight::get_data(model)
+  data <- insight::get_data(model, source = "mf", verbose = FALSE)
   wgts <- insight::get_weights(model, na_rm = TRUE)
 
   # Sanity Check for ZI
-  if (mi$is_zero_inflated) {
-    insight::format_warning(
+  if (mi$is_zero_inflated && verbose) {
+    insight::format_alert(
       "Non-refit parameter standardization is ignoring the zero-inflation component."
     )
     # would need to also get the binomial model matrix...
@@ -76,8 +78,8 @@ standardize_info.default <- function(model,
 
   # Type of effect size
   out$EffectSize_Type <- ifelse(types$Type == "interaction", "interaction",
-    ifelse(types$Link == "Association", "r",
-      ifelse(types$Link == "Difference", "d", NA)
+    ifelse(types$Link == "Association", "r", # nolint
+      ifelse(types$Link == "Difference", "d", NA) # nolint
     )
   )
 
@@ -117,10 +119,15 @@ standardize_info.default <- function(model,
     by = "Parameter", all = TRUE
   )
 
+  # sdy (see Mood 2009, 10.1093/esr/jcp006)
+  out <- merge(
+    out,
+    .std_info_predictors_sdy(model, model_matrix, types, robust = robust, two_sd = two_sd, w = wgts),
+    by = "Parameter", all = TRUE
+  )
+
   # Pseudo (for LMM)
-  if (include_pseudo &&
-    mi$is_mixed &&
-    length(insight::find_random(model)$random) == 1) {
+  if (include_pseudo && mi$is_mixed && length(insight::find_random(model)$random) == 1L) {
     out <- merge(
       out,
       .std_info_pseudo(
@@ -130,7 +137,8 @@ standardize_info.default <- function(model,
         data,
         types = types$Type,
         robust = robust,
-        two_sd = two_sd
+        two_sd = two_sd,
+        verbose = verbose
       )
     )
   }
@@ -141,7 +149,7 @@ standardize_info.default <- function(model,
   row.names(out) <- NULL
 
   # Remove all means for now (because it's not used)
-  out <- out[!grepl("Mean_", names(out))]
+  out <- out[!grepl("Mean_", names(out), fixed = TRUE)]
 
   # Select only desired columns
   # if(method == "all") method <- c("smart", "basic")
@@ -290,6 +298,33 @@ standardize_info.default <- function(model,
 
 
 
+# Predictors - sdy ------------------------------------------------------------
+
+
+#' @keywords internal
+.std_info_predictors_sdy <- function(model,
+                                     model_matrix,
+                                     types,
+                                     ...) {
+  deviations <- NA_real_
+  # fitted values
+  fitted_values <- .safe(stats::fitted(model))
+  if (!is.null(fitted_values)) {
+    deviations <- 1 / sum(c(stats::sd(fitted_values), sqrt(pi^2 / 3)))
+  }
+
+  # Out
+  data.frame(
+    Parameter = types$Parameter[seq_along(names(model_matrix))],
+    Deviation_SDy = deviations,
+    stringsAsFactors = FALSE
+  )
+}
+
+
+
+
+
 # Response ------------------------------------------------------------
 
 #' @keywords internal
@@ -303,8 +338,7 @@ standardize_info.default <- function(model,
     means <- deviations <- rep(NA_real_, length = length(names(model_matrix)))
     for (i in seq_along(names(model_matrix))) {
       var <- names(model_matrix)[i]
-      if (any(types$Parameter == var) &&
-        types$Link[types$Parameter == var] == "Difference") {
+      if (any(types$Parameter == var) && types$Link[types$Parameter == var] == "Difference") {
         parent_var <- types$Variable[types$Parameter == var]
         intercept <- unique(data[[parent_var]])[1]
         response_at_intercept <- response[data[[parent_var]] == intercept]
@@ -348,7 +382,7 @@ standardize_info.default <- function(model,
   }
 
   if (info$is_linear) {
-    if (robust == FALSE) {
+    if (!robust) {
       sd_y <- datawizard::weighted_sd(response, w)
       mean_y <- datawizard::weighted_mean(response, w)
     } else {
@@ -381,9 +415,10 @@ standardize_info.default <- function(model,
                              types,
                              robust = FALSE,
                              two_sd = FALSE,
+                             verbose = verbose,
                              ...) {
-  if (robust) {
-    insight::format_warning("`robust` standardization not available for `pseudo` method.")
+  if (robust && verbose) {
+    insight::format_alert("`robust` standardization not available for `pseudo` method.")
   }
 
   insight::check_if_installed("performance")
@@ -416,7 +451,8 @@ standardize_info.default <- function(model,
 
   ## test "within"s are fully "within"
   # only relevant to numeric predictors that can have variance
-  if (any(check_within <- is_within & types == "numeric")) {
+  check_within <- is_within & types == "numeric"
+  if (any(check_within)) {
     p_check_within <- params[check_within]
     temp_d <- data.frame(model_matrix[, p_check_within, drop = FALSE])
     colnames(temp_d) <- paste0("W", seq_len(ncol(temp_d))) # overwrite because can't deal with ":"
@@ -433,10 +469,10 @@ standardize_info.default <- function(model,
     }) > 0.01
     also_between <- p_check_within[has_lvl2_var]
 
-    if (length(also_between)) {
-      insight::format_warning(
+    if (length(also_between) && verbose) {
+      insight::format_alert(
         "The following within-group terms have between-group variance:",
-        paste0(also_between, collapse = ", "),
+        toString(also_between),
         "This can inflate standardized within-group parameters associated with these terms.",
         "See `help(\"demean\", package = \"datawizard\")` for modeling between- and within-subject effects."
       )
@@ -531,7 +567,7 @@ standardize_info.default <- function(model,
     response <- as.numeric(data[, variable])
   }
 
-  if (robust == FALSE) {
+  if (!robust) {
     sd_x <- datawizard::weighted_sd(response, weights)
     mean_x <- datawizard::weighted_mean(response, weights)
   } else {
