@@ -159,7 +159,7 @@
   if ("ci_digits" %in% names(dot.arguments)) {
     attr(params, "ci_digits") <- dot.arguments[["ci_digits"]]
   } else {
-    attr(params, "ci_digits") <- 2
+    attr(params, "ci_digits") <- NULL
   }
 
   if ("p_digits" %in% names(dot.arguments)) {
@@ -213,16 +213,16 @@
 
   switch(tolower(ci_method),
     # abbreviations
-    "eti" = ,
-    "hdi" = ,
-    "si" = toupper(ci_method),
+    eti = ,
+    hdi = ,
+    si = toupper(ci_method),
     # named after people
-    "satterthwaite" = ,
-    "kenward" = ,
-    "wald" = insight::format_capitalize(ci_method),
+    satterthwaite = ,
+    kenward = ,
+    wald = insight::format_capitalize(ci_method),
     # special cases
-    "bci" = ,
-    "bcai" = "BCa",
+    bci = ,
+    bcai = "BCa",
     # no change otherwise
     ci_method
   )
@@ -236,11 +236,11 @@
     name <- attributes(s)$estName
     if (!is.null(name)) {
       coef_col <- switch(name,
-        "prob"       = "Probability",
-        "odds.ratio" = "Odds Ratio",
-        "emmean"     = "Marginal Means",
-        "rate"       = "Estimated Counts",
-        "ratio"      = "Ratio",
+        prob       = "Probability",
+        odds.ratio = "Odds Ratio",
+        emmean     = "Marginal Means",
+        rate       = "Estimated Counts",
+        ratio      = "Ratio",
         "Coefficient"
       )
     }
@@ -251,7 +251,11 @@
       } else if ((info$is_binomial && info$is_logit) || info$is_ordinal || info$is_multinomial || info$is_categorical) {
         coef_col <- "Odds Ratio"
       } else if (info$is_binomial && !info$is_logit) {
-        coef_col <- "Risk Ratio"
+        if (info$link_function == "identity") {
+          coef_col <- "Exp. Risk"
+        } else {
+          coef_col <- "Risk Ratio"
+        }
       } else if (info$is_count) {
         coef_col <- "IRR"
       }
@@ -261,7 +265,11 @@
       } else if ((info$is_binomial && info$is_logit) || info$is_ordinal || info$is_multinomial || info$is_categorical) {
         coef_col <- "Log-Odds"
       } else if (info$is_binomial && !info$is_logit) {
-        coef_col <- "Log-Risk"
+        if (info$link_function == "identity") {
+          coef_col <- "Risk"
+        } else {
+          coef_col <- "Log-Risk"
+        }
       } else if (info$is_count) {
         coef_col <- "Log-Mean"
       }
@@ -292,7 +300,17 @@
     return(params)
   }
 
-  columns <- grepl(pattern = "^(Coefficient|Mean|Median|MAP|Std_Coefficient|CI_|Std_CI)", colnames(params))
+  # pattern for marginaleffects objects
+  if (!is.null(attr(params, "coefficient_name"))) {
+    pattern <- sprintf(
+      "^(Coefficient|Mean|Median|MAP|Std_Coefficient|%s|CI_|Std_CI)",
+      attr(params, "coefficient_name")
+    )
+  } else {
+    pattern <- "^(Coefficient|Mean|Median|MAP|Std_Coefficient|CI_|Std_CI)"
+  }
+
+  columns <- grepl(pattern = pattern, colnames(params))
   if (any(columns)) {
     if (inherits(model, "mvord")) {
       rows <- params$Component != "correlation"
@@ -376,7 +394,7 @@
   if ("ci_digits" %in% names(dot.arguments)) {
     attr(params, "ci_digits") <- eval(dot.arguments[["ci_digits"]])
   } else {
-    attr(params, "ci_digits") <- 2
+    attr(params, "ci_digits") <- NULL
   }
 
   if ("p_digits" %in% names(dot.arguments)) {
