@@ -1,13 +1,13 @@
-requiet("estimatr")
-
 test_that("multivariate used to break: Insight Issue #618", {
+  skip_if_not_installed("estimatr")
+
   # multivariate
-  mod1 <- lm_robust(cbind(mpg, qsec) ~ cyl + disp, data = mtcars)
+  mod1 <- estimatr::lm_robust(cbind(mpg, qsec) ~ cyl + disp, data = mtcars)
   m <- model_parameters(mod1)
   expect_s3_class(m, "parameters_model")
 
   # univariate
-  mod2 <- lm_robust(mpg ~ cyl + disp, data = mtcars)
+  mod2 <- estimatr::lm_robust(mpg ~ cyl + disp, data = mtcars)
   m <- model_parameters(mod2)
   expect_s3_class(m, "parameters_model")
 })
